Enum xml_builder::XMLError [−][src]
Error type thrown by this crate
Variants
WrongInsert(String)
Tuple Fields
0: StringThrown when the given element cannot be inserted into the XML object tree.
WriteError(String)
Tuple Fields
0: StringThrown when the given Writer cannot be written to.