XMLElement

Struct XMLElement 

pub struct XMLElement { /* private fields */ }
Structure representing an XML element field.

Implementations

Source

impl XMLElement

pub fn new(name: &str) -> Self

Instantiates a new XMLElement object.

Arguments
  • name - A string slice that holds the name of the XML element.
pub const fn enable_attributes_sorting(&mut self)

Enables attributes sorting.

pub const fn disable_attributes_sorting(&mut self)

Disables attributes sorting.

pub fn add_attribute(&mut self, name: &str, value: &str)

Adds the given name/value attribute to the XMLElement.

Arguments
  • name - A string slice that holds the name of the attribute
  • value - A string slice that holds the value of the attribute
pub fn add_child(&mut self, element: Self) -> Result<()>

Adds a new XMLElement child object to the references XMLElement.

Raises XMLError if trying to add a child to a text XMLElement.

Arguments
  • element - A XMLElement object to add as child
pub fn add_text(&mut self, text: String) -> Result<()>

Adds text content to a XMLElement object.

Raises XMLError if trying to add text to a non-empty object.

Arguments
  • text - A string containing the text to add to the object
pub fn render<W: Write>( &self, writer: &mut W, should_sort: bool, should_indent: bool, should_break_lines: bool, should_expand_empty_tags: bool, ) -> Result<()>

Renders an XMLElement object into the specified writer implementing Write trait.

Does not take ownership of the object.

Arguments
  • writer - An object to render the referenced XMLElement to